@@ -145,14 +145,14 @@ class CSVDedupe(csvhelpers.CSVCommand) :
 
         # Add any parents with no clustered exact_dups but with exact dupes to expanded_clustered_dupes
         # or else they are omitted counted as non duplicates.
-        for row, exact_dups in parents.items():
-            if row not in rows_used and exact_dups is not None and len(exact_dups) > 0:
-                new_cluster = [row]
-                new_cluster.extend(exact_dups)
-                new_scores = [1.0]
-                new_scores.extend([1.0] * len(exact_dups))
-                expanded_clustered_dupes.append((new_cluster, new_scores))
-            
+        # for row, exact_dups in parents.items():
+        #     if row not in rows_used and exact_dups is not None and len(exact_dups) > 0:
+        #         new_cluster = [row]
+        #         new_cluster.extend(exact_dups)
+        #         new_scores = [1.0]
+        #         new_scores.extend([1.0] * len(exact_dups))
+        #         expanded_clustered_dupes.append((new_cluster, new_scores))
+        #
         clustered_dupes = expanded_clustered_dupes
 
         logging.info('# duplicate sets %s' % len(clustered_dupes))
